@@ -1,5 +1,3 @@
 from django.urls import path
 
-urlpatterns = [
-    
-]
\ No newline at end of file
+urlpatterns = []
